Learn R Programming

rfishbase (version 2.1.2)

c_code: c_code

Description

return a table of country information for the requested c_code, as reported in FishBASE.org

Usage

c_code(c_code, server = getOption("FISHBASE_API", FISHBASE_API),
  fields = "", limit = 500)

Arguments

c_code

a C_Code or list of C_Codes (FishBase country code)

server

base URL to the FishBase API (by default). For SeaLifeBase, use https://fishbase.ropensci.org/sealifebase

fields

a character vector specifying which fields (columns) should be returned. By default, all available columns recognized by the parser are returned. This option can be used to limit the amount of data transfered over the network if only certain columns are needed.

limit

The maximum number of matches from a single API call (e.g. per species). Function will warn if this needs to be increased, otherwise can be left as is.

Details

e.g. http://www.fishbase.us/Country

Examples

Run this code
# NOT RUN {
c_code(440)
# }

Run the code above in your browser using DataLab