Description
return a table of species fooditems
Usage
length_freq(species_list = NULL, fields = NULL, query = NULL,
limit = 200, server = getOption("FISHBASE_API", FISHBASE_API), ...)Arguments
species_list
A vector of scientific names (each element as "genus species"). If empty, the table will be loaded up to the limit. This makes it possible to load an entire table without knowledge of the species in the table, thus avoiding uneccesary API calls.
fields
a character vector specifying which fields (columns) should be returned. By default,
all available columns recognized by the parser are returned. This option can be used to limit the amount
of data transfered over the network if only certain columns are needed.
query
a named list specifying specific subsets of fields.
limit
The maximum number of matches from a single API call (e.g. per species). Function
will warn if this needs to be increased, otherwise can be left as is.
server
base URL to the FishBase API (by default). For SeaLifeBase, use https://fishbase.ropensci.org/sealifebase
...
additional arguments to httr::GET
Value
a table of length_freq information by species; see details
References
http://www.fishbase.org/manual/english/lengthfrequency.htm
Examples
Run this code# NOT RUN {
length_freq("Oreochromis niloticus")
# }
Run the code above in your browser using DataLab