Learn R Programming

rfishbase (version 2.1.2)

load_taxa: load_taxa

Description

Load or update the taxa list

Usage

load_taxa(update = FALSE, cache = TRUE, server = getOption("FISHBASE_API",
  FISHBASE_API), limit = 5000L)

Arguments

update

logical, should we query the API to update the available list?

cache

should we cache the updated version throughout this session? (default TRUE, leave as is)

server

base URL to the FishBase API (by default). For SeaLifeBase, use https://fishbase.ropensci.org/sealifebase

limit

The maximum number of matches from a single API call (e.g. per species). Function will warn if this needs to be increased, otherwise can be left as is.

Value

the taxa list