references(codes = NULL, fields = NULL, server = getOption("FISHBASE_API",
FISHBASE_API))
Arguments
codes
One or more Fishbase reference numbers, matching the RefNo
field
fields
a character vector specifying which fields (columns) should be
returned. By default, all available columns recognized by the parser are
returned. This option can be used to limit the amount of data transfered
over the network if only certain columns are needed.
server
base URL to the FishBase API (by default). For SeaLifeBase,
use https://fishbase.ropensci.org/sealifebase