species_list(Class = NULL, Order = NULL, Family = NULL,
SubFamily = NULL, Genus = NULL, Species = NULL, SpecCode = NULL,
SpeciesRefNo = NULL, all_taxa = load_taxa())
Arguments
Class
Request all species in this taxonomic Class
Order
Request all species in this taxonomic Order
Family
Request all species in this taxonomic Family
SubFamily
Request all species in this taxonomic SubFamily
Genus
Request all species in this taxonomic Genus
Species
Request all species in this taxonomic Species
SpecCode
Request species name of species matching this SpecCode
SpeciesRefNo
Request species name of all species matching this SpeciesRefNo
all_taxa
The data.frame of all taxa used for the lookup. By default will be loaded
from cache if available, otherwise must be downloaded from the server; about 13 MB, may be
slow.
Details
The first time the function is called it will download and cache the complete