Learn R Programming

rfishbase (version 2.1.2)

validate_names: validate_names

Description

Check for alternate versions of a scientific name and return the names FishBase recognizes as valid

Usage

validate_names(species_list, limit = 50, server = getOption("FISHBASE_API",
  FISHBASE_API))

Arguments

species_list

A vector of scientific names (each element as "genus species"). If empty, the table will be loaded up to the limit. This makes it possible to load an entire table without knowledge of the species in the table, thus avoiding uneccesary API calls.

limit

The maximum number of matches from a single API call (e.g. per species). Function will warn if this needs to be increased, otherwise can be left as is.

server

base URL to the FishBase API (by default). For SeaLifeBase, use https://fishbase.ropensci.org/sealifebase

Value

a string of the validated names