If more than one scientific name matches the common name (e.g. "trout"), the function
will simply return a list of all matching scientific names. If given more than one common name,
the resulting strings of matching scientific names are simply concatenated.
Setting the language used explicitly will decrease the data transferred and speed up the function.
The limit default is quite high in this call, as it corresponds to the number of common names that
match a given species, including different languages and countries.