Learn R Programming

rfishbase (version 2.1.2)

list_fields: list_fields

Description

list fields

Usage

list_fields(fields, server = getOption("FISHBASE_API", FISHBASE_API),
  implemented_only = TRUE)

Arguments

fields

field (column name) to search for

server

base URL to the FishBase API (by default). For SeaLifeBase, use https://fishbase.ropensci.org/sealifebase

implemented_only

by default, only return those tables that have been implemented.

Value

a data frame listing the table names (matching function names in rfishbase) and the matching column names those tables have implemented.

Details

method will use partial matching. Hence "Temp" will match column names such as "TempMin" and "TempMax", but "MinTemp" will not. Likewise, neither "Minimum" or "Temperature" will match "TempMin", so begin with the shortest query possible and refine based on search results when necessary. Note also that there is no guarentee that the same column has the same value or same meaning in different tables.

Examples

Run this code
# NOT RUN {
list_fields("Temp")
# }

Run the code above in your browser using DataLab