Load or update the taxa list
load_taxa(update = FALSE, cache = TRUE, server = getOption("FISHBASE_API",
FISHBASE_API), limit = 5000L)logical, should we query the API to update the available list?
should we cache the updated version throughout this session? (default TRUE, leave as is)
base URL to the FishBase API (by default). For SeaLifeBase, use https://fishbase.ropensci.org/sealifebase
The maximum number of matches from a single API call (e.g. per species). Function will warn if this needs to be increased, otherwise can be left as is.
the taxa list