Usage
synonyms(species_list, limit = 50, server = getOption("FISHBASE_API", FISHBASE_API), fields = c("SynGenus", "SynSpecies", "Valid", "Misspelling", "Status", "Synonymy", "Combination", "SpecCode", "SynCode", "CoL_ID", "TSN", "WoRMS_ID"))
Arguments
species_list
A vector of scientific names (each element as "genus species"). If empty, the table will be loaded up to the limit. This makes it possible to load an entire table without knowledge of the species in the table, thus avoiding uneccesary API calls.
limit
The maximum number of matches from a single API call (e.g. per species). Function
will warn if this needs to be increased, otherwise can be left as is.
server
base URL to the FishBase API (by default). For SeaLifeBase, use http://fishbase.ropensci.org/sealifebase
fields
a character vector specifying which fields (columns) should be returned. By default,
all available columns recognized by the parser are returned. This option can be used to limit the amount
of data transfered over the network if only certain columns are needed.